Introduction
============

.. image:: https://badge.fury.io/py/bottle-rest.png
    :target: https://pypi.python.org/pypi/bottle-rest

.. image:: https://img.shields.io/pypi/dm/bottle-rest.svg
    :target: https://pypi.python.org/pypi/bottle-rest

.. image:: https://readthedocs.org/projects/bottle-rest/badge/?version=latest
    :target: http://bottle-rest.readthedocs.org/

.. image:: https://img.shields.io/github/issues/Bystroushaak/bottle-rest.svg
    :target: https://github.com/Bystroushaak/bottle-rest/issues

.. image:: https://img.shields.io/pypi/l/bottle-rest.svg

This package is used to make easier creating REST applications using
`Bottle <http://bottlepy.org>`_ web framework.

Documentation
-------------

Full module documentation and description can be found at Read the Docs:

- http://bottle-rest.readthedocs.org/
